# Sidd-Package
Siddharth's first and experimental Python Package 


```
C:\Users\siddpc\OneDrive\Desktop>pip install siddp6

```

```
C:\Users\siddpc\OneDrive\Desktop>python

Python 3.10.1 (tags/v3.10.1:2cd268a, Dec  6 2021, 19:10:37) [MSC v.1929 64 bit (AMD64)] on win32
Type "help", "copyright", "credits" or "license" for more information.

>>> import sidd
>>> sidd.who()
I am Siddhatha
>>> sidd.hello()
Hello Siddharth
>>> sidd.bye()
Bye Siddharth
>>> ^Z
```

![image](https://user-images.githubusercontent.com/91800813/202282981-5a78dbd8-59e9-4636-bbc4-ab787455b066.png)
